# pseudo_generate

pseudo_generate est un petit package Python permettant de générer facilement des pseudonymes d'étudiants aléatoires depuis la ligne de commande.

---

## installation

```bash
pip install pseudo-generate

## utilisation

```bash

enregistrement genere pseudo --nombre (nombre)


